@@ -1,4 +1,8 @@
-VERSION = (0, 2, 0)
+import sys
+
+VERSION = (0, 2, 1)
+
+FROZEN = getattr(sys, u'frozen', False)
 
 
 def get_version():
